/*
 * [ExportPGPKeywordsToHTML.java]
 *
 * Summary: Generate an HTML table of PGP words used to describe public keys.
 *
 * Copyright: (c) 2011-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2011-02-16 initial release.
 */
package com.mindprod.pgpkeywords;

import com.mindprod.common18.BigDate;
import com.mindprod.common18.ST;

import static java.lang.System.*;

/**
 * Generate an HTML table of PGP words used to describe public keys.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2011-02-16 initial release.
 * @since 2011-02-16
 */
final class ExportPGPKeywordsToHTML
    {
    private static final String[] evenWords = {
            "aardvark",
            "absurd",
            "accrue",
            "acme",
            "adrift",
            "adult",
            "afflict",
            "ahead",
            "aimless",
            "Algol",
            "allow",
            "alone",
            "ammo",
            "ancient",
            "apple",
            "artist",
            "assume",
            "Athens",
            "atlas",
            "Aztec",
            "baboon",
            "backfield",
            "backward",
            "banjo",
            "beaming",
            "bedlamp",
            "beehive",
            "beeswax",
            "befriend",
            "Belfast",
            "berserk",
            "billiard",
            "bison",
            "blackjack",
            "blockade",
            "blowtorch",
            "bluebird",
            "bombast",
            "bookshelf",
            "brackish",
            "breadline",
            "breakup",
            "brickyard",
            "briefcase",
            "Burbank",
            "button",
            "buzzard",
            "cement",
            "chairlift",
            "chatter",
            "checkup",
            "chisel",
            "choking",
            "chopper",
            "Christmas",
            "clamshell",
            "classic",
            "classroom",
            "cleanup",
            "clockwork",
            "cobra",
            "commence",
            "concert",
            "cowbell",
            "crackdown",
            "cranky",
            "crowfoot",
            "crucial",
            "crumpled",
            "crusade",
            "cubic",
            "dashboard",
            "deadbolt",
            "deckhand",
            "dogsled",
            "dragnet",
            "drainage",
            "dreadful",
            "drifter",
            "dropper",
            "drumbeat",
            "drunken",
            "Dupont",
            "dwelling",
            "eating",
            "edict",
            "egghead",
            "eightball",
            "endorse",
            "endow",
            "enlist",
            "erase",
            "escape",
            "exceed",
            "eyeglass",
            "eyetooth",
            "facial",
            "fallout",
            "flagpole",
            "flatfoot",
            "flytrap",
            "fracture",
            "framework",
            "freedom",
            "frighten",
            "gazelle",
            "Geiger",
            "glitter",
            "glucose",
            "goggles",
            "goldfish",
            "gremlin",
            "guidance",
            "hamlet",
            "highchair",
            "hockey",
            "indoors",
            "indulge",
            "inverse",
            "involve",
            "island",
            "jawbone",
            "keyboard",
            "kickoff",
            "kiwi",
            "klaxon",
            "locale",
            "lockup",
            "merit",
            "minnow",
            "miser",
            "Mohawk",
            "mural",
            "music",
            "necklace",
            "Neptune",
            "newborn",
            "nightbird",
            "Oakland",
            "obtuse",
            "offload",
            "optic",
            "orca",
            "payday",
            "peachy",
            "pheasant",
            "physique",
            "playhouse",
            "Pluto",
            "preclude",
            "prefer",
            "preshrunk",
            "printer",
            "prowler",
            "pupil",
            "puppy",
            "python",
            "quadrant",
            "quiver",
            "quota",
            "ragtime",
            "ratchet",
            "rebirth",
            "reform",
            "regain",
            "reindeer",
            "rematch",
            "repay",
            "retouch",
            "revenge",
            "reward",
            "rhythm",
            "ribcage",
            "ringbolt",
            "robust",
            "rocker",
            "ruffled",
            "sailboat",
            "sawdust",
            "scallion",
            "scenic",
            "scorecard",
            "Scotland",
            "seabird",
            "select",
            "sentence",
            "shadow",
            "shamrock",
            "showgirl",
            "skullcap",
            "skydive",
            "slingshot",
            "slowdown",
            "snapline",
            "snapshot",
            "snowcap",
            "snowslide",
            "solo",
            "southward",
            "soybean",
            "spaniel",
            "spearhead",
            "spellbind",
            "spheroid",
            "spigot",
            "spindle",
            "spyglass",
            "stagehand",
            "stagnate",
            "stairway",
            "standard",
            "stapler",
            "steamship",
            "sterling",
            "stockman",
            "stopwatch",
            "stormy",
            "sugar",
            "surmount",
            "suspense",
            "sweatband",
            "swelter",
            "tactics",
            "talon",
            "tapeworm",
            "tempest",
            "tiger",
            "tissue",
            "tonic",
            "topmost",
            "tracker",
            "transit",
            "trauma",
            "treadmill",
            "Trojan",
            "trouble",
            "tumor",
            "tunnel",
            "tycoon",
            "uncut",
            "unearth",
            "unwind",
            "uproot",
            "upset",
            "upshot",
            "vapor",
            "village",
            "virus",
            "Vulcan",
            "waffle",
            "wallet",
            "watchword",
            "wayside",
            "willow",
            "woodlark",
            "Zulu" };

    private static final String[] oddWords = {
            "adroitness",
            "adviser",
            "aftermath",
            "aggregate",
            "alkali",
            "almighty",
            "amulet",
            "amusement",
            "antenna",
            "applicant",
            "Apollo",
            "armistice",
            "article",
            "asteroid",
            "Atlantic",
            "atmosphere",
            "autopsy",
            "Babylon",
            "backwater",
            "barbecue",
            "belowground",
            "bifocals",
            "bodyguard",
            "bookseller",
            "borderline",
            "bottomless",
            "Bradbury",
            "bravado",
            "Brazilian",
            "breakaway",
            "Burlington",
            "businessman",
            "butterfat",
            "Camelot",
            "candidate",
            "cannonball",
            "Capricorn",
            "caravan",
            "caretaker",
            "celebrate",
            "cellulose",
            "certify",
            "chambermaid",
            "Cherokee",
            "Chicago",
            "clergyman",
            "coherence",
            "combustion",
            "commando",
            "company",
            "component",
            "concurrent",
            "confidence",
            "conformist",
            "congregate",
            "consensus",
            "consulting",
            "corporate",
            "corrosion",
            "councilman",
            "crossover",
            "crucifix",
            "cumbersome",
            "customer",
            "Dakota",
            "decadence",
            "December",
            "decimal",
            "designing",
            "detector",
            "detergent",
            "determine",
            "dictator",
            "dinosaur",
            "direction",
            "disable",
            "disbelief",
            "disruptive",
            "distortion",
            "document",
            "embezzle",
            "enchanting",
            "enrollment",
            "enterprise",
            "equation",
            "equipment",
            "escapade",
            "Eskimo",
            "everyday",
            "examine",
            "existence",
            "exodus",
            "fascinate",
            "filament",
            "finicky",
            "forever",
            "fortitude",
            "frequency",
            "gadgetry",
            "Galveston",
            "getaway",
            "glossary",
            "gossamer",
            "graduate",
            "gravity",
            "guitarist",
            "hamburger",
            "Hamilton",
            "handiwork",
            "hazardous",
            "headwaters",
            "hemisphere",
            "hesitate",
            "hideaway",
            "holiness",
            "hurricane",
            "hydraulic",
            "impartial",
            "impetus",
            "inception",
            "indigo",
            "inertia",
            "infancy",
            "inferno",
            "informant",
            "insincere",
            "insurgent",
            "integrate",
            "intention",
            "inventive",
            "Istanbul",
            "Jamaica",
            "Jupiter",
            "leprosy",
            "letterhead",
            "liberty",
            "maritime",
            "matchmaker",
            "maverick",
            "Medusa",
            "megaton",
            "microscope",
            "microwave",
            "midsummer",
            "millionaire",
            "miracle",
            "misnomer",
            "molasses",
            "molecule",
            "Montana",
            "monument",
            "mosquito",
            "narrative",
            "nebula",
            "newsletter",
            "Norwegian",
            "October",
            "Ohio",
            "onlooker",
            "opulent",
            "Orlando",
            "outfielder",
            "Pacific",
            "pandemic",
            "Pandora",
            "paperweight",
            "paragon",
            "paragraph",
            "paramount",
            "passenger",
            "pedigree",
            "Pegasus",
            "penetrate",
            "perceptive",
            "performance",
            "pharmacy",
            "phonetic",
            "photograph",
            "pioneer",
            "pocketful",
            "politeness",
            "positive",
            "potato",
            "processor",
            "provincial",
            "proximate",
            "puberty",
            "publisher",
            "pyramid",
            "quantity",
            "racketeer",
            "rebellion",
            "recipe",
            "recover",
            "repellent",
            "replica",
            "reproduce",
            "resistor",
            "responsive",
            "retraction",
            "retrieval",
            "retrospect",
            "revenue",
            "revival",
            "revolver",
            "sandalwood",
            "sardonic",
            "Saturday",
            "savagery",
            "scavenger",
            "sensation",
            "sociable",
            "souvenir",
            "specialist",
            "speculate",
            "stethoscope",
            "stupendous",
            "supportive",
            "surrender",
            "suspicious",
            "sympathy",
            "tambourine",
            "telephone",
            "therapist",
            "tobacco",
            "tolerance",
            "tomorrow",
            "torpedo",
            "tradition",
            "travesty",
            "trombonist",
            "truncated",
            "typewriter",
            "ultimate",
            "undaunted",
            "underfoot",
            "unicorn",
            "unify",
            "universe",
            "unravel",
            "upcoming",
            "vacancy",
            "vagabond",
            "vertigo",
            "Virginia",
            "visitor",
            "vocalist",
            "voyager",
            "warranty",
            "Waterloo",
            "whimsical",
            "Wichita",
            "Wilmington",
            "Wyoming",
            "yesteryear",
            "Yucatan"
    };

    private static final String DO_NOT_EDIT = "<!-- The following table was generated on " + BigDate.localToday().toString() + " by pgbkeywords.ExportPGPKeywordsToHTML. D o   n o t   e d i t . -->\n";

    /**
     * export either the even or odd table
     *
     * @param words which table of words to use.
     */
    private static void exportOneTable( String evenOdd, String[] words )
        {
        out.print( DO_NOT_EDIT +
                   "<table class=\"standard\"><caption class=\"hidden\">" + evenOdd + " PGP words</caption>\n" );
        // header
        out.print( "<thead><tr><th colspan=\"18\">" +
                   evenOdd + " PGP Words</th></tr>\n" );
        out.print( "<tr><th>&nbsp;</th>" );
        for ( int i = 0; i < 16; i++ )
            {
            out.print( "<th>" );
            out.print( ST.toLZHexString( i, 1 ).toUpperCase() );
            out.print( "</th>" );
            }
        out.print( "<th>&nbsp;</th></tr></thead>\n" );
        // footer
        out.print( "<tfoot>\n" );
        out.print( "<tr><th>&nbsp;</th>" );
        for ( int i = 0; i < 16; i++ )
            {
            out.print( "<th>" );
            out.print( ST.toLZHexString( i, 1 ).toUpperCase() );
            out.print( "</th>" );
            }
        out.print( " <th>&nbsp;</th></tr></tfoot>\n" );
        out.print( "<tbody>\n" );
        // 16x16 grid with left and right label.
        for ( int i = 0; i < 256; i++ )
            {
            if ( i % 16 == 0 )
                {
                out.print( "<tr><th>" );
                out.print( ST.toLZHexString( i / 16, 1 ).toUpperCase() );
                out.print( "</th>" );
                }
            out.print( "<td>" );
            out.print( words[ i ] );
            out.print( "</td>" );
            if ( i % 16 == 15 )
                {
                out.print( "<th>" );
                out.print( ST.toLZHexString( i / 16, 1 ).toUpperCase() );
                out.print( "</th></tr>\n" );
                }
            }
        out.print( "</tbody>\n" );
        out.print( "</table>\n" );
        }

    /**
     * Generate an HTML table of PGP words used to describe public keys
     *
     * @param args not used
     */
    public static void main( String[] args )
        {
        exportOneTable( "Even two-syllable", evenWords );
        exportOneTable( "Odd three-syllable", oddWords );
        }
    }
